@@ -1,12 +1,11 @@
-// Copyright (c) 2016-2017, The Tor Project, Inc. */
+// Copyright (c) 2016-2018, The Tor Project, Inc. */
 // See LICENSE for licensing information */
 
 //! FFI functions to announce Rust support during tor startup, only to be
 //! called from C.
 //!
 
-use libc::c_char;
-use tor_allocate::allocate_and_copy_string;
+use tor_log::{LogDomain, LogSeverity};
 
 /// Returns a short string to announce Rust support during startup.
 ///
@@ -17,10 +16,12 @@ use tor_allocate::allocate_and_copy_string;
 /// tor_free(rust_str);
 /// ```
 #[no_mangle]
-pub extern "C" fn rust_welcome_string() -> *mut c_char {
-    let rust_welcome = String::from(
+pub extern "C" fn rust_log_welcome_string() {
+    tor_log_msg!(
+        LogSeverity::Notice,
+        LogDomain::General,
+        "rust_log_welcome_string",
         "Tor is running with Rust integration. Please report \
-         any bugs you encounter.",
+         any bugs you encounter."
     );
-    allocate_and_copy_string(&rust_welcome)
 }
